@@ -17,10 +17,10 @@ struct Handlers
     JSONHandler::void_handler_t dict_end_handler{nullptr};
     JSONHandler::json_handler_t array_start_handler{nullptr};
     JSONHandler::void_handler_t array_end_handler{nullptr};
-    JSONHandler::void_handler_t final_handler{nullptr};
     std::map<std::string, std::shared_ptr<JSONHandler>> dict_handlers;
     std::shared_ptr<JSONHandler> fallback_dict_handler;
     std::shared_ptr<JSONHandler> array_item_handler;
+    std::shared_ptr<JSONHandler> fallback_handler;
 };
 
 class JSONHandler::Members
@@ -110,6 +110,12 @@ JSONHandler::addArrayHandlers(
     m->h.array_item_handler = ah;
 }
 
+void
+JSONHandler::addFallbackHandler(std::shared_ptr<JSONHandler> h)
+{
+    m->h.fallback_handler = std::move(h);
+}
+
 void
 JSONHandler::handle(std::string const& path, JSON j)
 {
@@ -169,6 +175,11 @@ JSONHandler::handle(std::string const& path, JSON j)
         return;
     }
 
+    if (m->h.fallback_handler) {
+        m->h.fallback_handler->handle(path, j);
+        return;
+    }
+
     // It would be nice to include information about what type the object was and what types were
     // allowed, but we're relying on schema validation to make sure input is properly structured
     // before calling the handlers. It would be different if this code were trying to be part of a
