@@ -1,6 +1,5 @@
 #include <qpdf/Pl_DCT.hh>
 
-#include "qpdf/QPDFLogger.hh"
 #include <qpdf/QIntC.hh>
 #include <qpdf/QTC.hh>
 
@@ -14,6 +13,23 @@
 
 namespace
 {
+    class FunctionCallbackConfig: public Pl_DCT::CompressConfig
+    {
+      public:
+        explicit FunctionCallbackConfig(std::function<void(jpeg_compress_struct*)> f) :
+            f(std::move(f))
+        {
+        }
+        ~FunctionCallbackConfig() override = default;
+        void
+        apply(jpeg_compress_struct* config) override
+        {
+            f(config);
+        };
+
+        std::function<void(jpeg_compress_struct*)> f;
+    };
+
     struct qpdf_jpeg_error_mgr
     {
         struct jpeg_error_mgr pub;
@@ -57,31 +73,52 @@ progress_monitor(j_common_ptr cinfo)
     }
 }
 
-Pl_DCT::Members::Members() :
-    action(a_decompress),
-    buf("DCT compressed image")
+class Pl_DCT::Members
 {
-}
+  public:
+    // For compression
+    Members(
+        JDIMENSION image_width,
+        JDIMENSION image_height,
+        int components,
+        J_COLOR_SPACE color_space,
+        CompressConfig* config_callback) :
+        action(a_compress),
+        buf("DCT uncompressed image"),
+        image_width(image_width),
+        image_height(image_height),
+        components(components),
+        color_space(color_space),
+        config_callback(config_callback)
+    {
+    }
 
-Pl_DCT::Members::Members(
-    JDIMENSION image_width,
-    JDIMENSION image_height,
-    int components,
-    J_COLOR_SPACE color_space,
-    CompressConfig* config_callback) :
-    action(a_compress),
-    buf("DCT uncompressed image"),
-    image_width(image_width),
-    image_height(image_height),
-    components(components),
-    color_space(color_space),
-    config_callback(config_callback)
-{
-}
+    // For decompression
+    Members() :
+        action(a_decompress),
+        buf("DCT compressed image")
+    {
+    }
+
+    Members(Members const&) = delete;
+
+    ~Members() = default;
+
+    action_e action;
+    Pl_Buffer buf;
+
+    // Used for compression
+    JDIMENSION image_width{0};
+    JDIMENSION image_height{0};
+    int components{1};
+    J_COLOR_SPACE color_space{JCS_GRAYSCALE};
+
+    CompressConfig* config_callback{nullptr};
+};
 
 Pl_DCT::Pl_DCT(char const* identifier, Pipeline* next) :
     Pipeline(identifier, next),
-    m(new Members())
+    m(std::make_unique<Members>())
 {
     if (!next) {
         throw std::logic_error("Attempt to create Pl_DCT with nullptr as next");
@@ -115,14 +152,13 @@ Pl_DCT::Pl_DCT(
     J_COLOR_SPACE color_space,
     CompressConfig* compress_callback) :
     Pipeline(identifier, next),
-    m(new Members(image_width, image_height, components, color_space, compress_callback))
+    m(std::make_unique<Members>(
+        image_width, image_height, components, color_space, compress_callback))
 {
 }
 
-Pl_DCT::~Pl_DCT() // NOLINT (modernize-use-equals-default)
-{
-    // Must be explicit and not inline -- see QPDF_DLL_CLASS in README-maintainer
-}
+// Must be explicit and not inline -- see QPDF_DLL_CLASS in README-maintainer
+Pl_DCT::~Pl_DCT() = default;
 
 void
 Pl_DCT::write(unsigned char const* data, size_t len)
@@ -387,3 +423,9 @@ Pl_DCT::decompress(void* cinfo_p, Buffer* b)
     (void)jpeg_finish_decompress(cinfo);
     next()->finish();
 }
+
+std::unique_ptr<Pl_DCT::CompressConfig>
+Pl_DCT::make_compress_config(std::function<void(jpeg_compress_struct*)> f)
+{
+    return std::make_unique<FunctionCallbackConfig>(f);
+}
