@@ -139,6 +139,13 @@ QPDFJob::Config::compressionLevel(std::string const& parameter)
     return this;
 }
 
+QPDFJob::Config*
+QPDFJob::Config::jpegQuality(std::string const& parameter)
+{
+    o.m->jpeg_quality = QUtil::string_to_int(parameter.c_str());
+    return this;
+}
+
 QPDFJob::Config*
 QPDFJob::Config::copyEncryption(std::string const& parameter)
 {
@@ -531,6 +538,13 @@ QPDFJob::Config::removePageLabels()
     return this;
 }
 
+QPDFJob::Config*
+QPDFJob::Config::removeStructure()
+{
+    o.m->remove_structure = true;
+    return this;
+}
+
 QPDFJob::Config*
 QPDFJob::Config::reportMemoryUsage()
 {
