@@ -1,5 +1,6 @@
 #include <qpdf/QPDFParser.hh>
 
+#include <qpdf/BufferInputSource.hh>
 #include <qpdf/QPDF.hh>
 #include <qpdf/QPDFObjGen.hh>
 #include <qpdf/QPDFObjectHandle.hh>
@@ -10,8 +11,105 @@
 
 #include <memory>
 
+using namespace std::literals;
+using namespace qpdf;
+
 using ObjectPtr = std::shared_ptr<QPDFObject>;
 
+QPDFObjectHandle
+QPDFParser::parse(InputSource& input, std::string const& object_description, QPDF* context)
+{
+    qpdf::Tokenizer tokenizer;
+    bool empty = false;
+    return QPDFParser(
+               input,
+               make_description(input.getName(), object_description),
+               object_description,
+               tokenizer,
+               nullptr,
+               context,
+               false)
+        .parse(empty, false);
+}
+
+QPDFObjectHandle
+QPDFParser::parse_content(
+    InputSource& input,
+    std::shared_ptr<QPDFObject::Description> sp_description,
+    qpdf::Tokenizer& tokenizer,
+    QPDF* context)
+{
+    bool empty = false;
+    return QPDFParser(
+               input, std::move(sp_description), "content", tokenizer, nullptr, context, true)
+        .parse(empty, true);
+}
+
+QPDFObjectHandle
+QPDFParser::parse(
+    InputSource& input,
+    std::string const& object_description,
+    QPDFTokenizer& tokenizer,
+    bool& empty,
+    QPDFObjectHandle::StringDecrypter* decrypter,
+    QPDF* context)
+{
+    return QPDFParser(
+               input,
+               make_description(input.getName(), object_description),
+               object_description,
+               *tokenizer.m,
+               decrypter,
+               context,
+               false)
+        .parse(empty, false);
+}
+
+std::pair<QPDFObjectHandle, bool>
+QPDFParser::parse(
+    InputSource& input,
+    std::string const& object_description,
+    qpdf::Tokenizer& tokenizer,
+    QPDFObjectHandle::StringDecrypter* decrypter,
+    QPDF& context,
+    bool sanity_checks)
+{
+    bool empty{false};
+    auto result = QPDFParser(
+                      input,
+                      make_description(input.getName(), object_description),
+                      object_description,
+                      tokenizer,
+                      decrypter,
+                      &context,
+                      true,
+                      0,
+                      0,
+                      sanity_checks)
+                      .parse(empty, false);
+    return {result, empty};
+}
+
+std::pair<QPDFObjectHandle, bool>
+QPDFParser::parse(
+    is::OffsetBuffer& input, int stream_id, int obj_id, qpdf::Tokenizer& tokenizer, QPDF& context)
+{
+    bool empty{false};
+    auto result = QPDFParser(
+                      input,
+                      std::make_shared<QPDFObject::Description>(
+                          QPDFObject::ObjStreamDescr(stream_id, obj_id)),
+                      "",
+                      tokenizer,
+                      nullptr,
+                      &context,
+                      true,
+                      stream_id,
+                      obj_id)
+                      .parse(empty, false);
+    return {result, empty};
+}
+
 QPDFObjectHandle
 QPDFParser::parse(bool& empty, bool content_stream)
 {
@@ -204,7 +302,7 @@ QPDFParser::parseRemainder(bool content_stream)
             continue;
 
         case QPDFTokenizer::tt_array_close:
-            if (bad_count && !max_bad_count) {
+            if ((bad_count || sanity_checks) && !max_bad_count) {
                 // Trigger warning.
                 (void)tooManyBadTokens();
                 return {QPDFObject::create<QPDF_Null>()};
@@ -235,7 +333,7 @@ QPDFParser::parseRemainder(bool content_stream)
             continue;
 
         case QPDFTokenizer::tt_dict_close:
-            if (bad_count && !max_bad_count) {
+            if ((bad_count || sanity_checks) && !max_bad_count) {
                 // Trigger warning.
                 (void)tooManyBadTokens();
                 return {QPDFObject::create<QPDF_Null>()};
@@ -420,7 +518,8 @@ template <typename T, typename... Args>
 void
 QPDFParser::addScalar(Args&&... args)
 {
-    if (bad_count && (frame->olist.size() > 5'000 || frame->dict.size() > 5'000)) {
+    if ((bad_count || sanity_checks) &&
+        (frame->olist.size() > 5'000 || frame->dict.size() > 5'000)) {
         // Stop adding scalars. We are going to abort when the close token or a bad token is
         // encountered.
         max_bad_count = 0;
@@ -478,10 +577,15 @@ bool
 QPDFParser::tooManyBadTokens()
 {
     if (frame->olist.size() > 5'000 || frame->dict.size() > 5'000) {
+        if (bad_count) {
+            warn(
+                "encountered errors while parsing an array or dictionary with more than 5000 "
+                "elements; giving up on reading object");
+            return true;
+        }
         warn(
-            "encountered errors while parsing an array or dictionary with more than 5000 "
-            "elements; giving up on reading object");
-        return true;
+            "encountered an array or dictionary with more than 5000 elements during xref recovery; "
+            "giving up on reading object");
     }
     if (--max_bad_count > 0 && good_count > 4) {
         good_count = 0;
@@ -524,7 +628,13 @@ QPDFParser::warnDuplicateKey()
 void
 QPDFParser::warn(qpdf_offset_t offset, std::string const& msg) const
 {
-    warn(QPDFExc(qpdf_e_damaged_pdf, input.getName(), object_description, offset, msg));
+    if (stream_id) {
+        std::string descr = "object "s + std::to_string(obj_id) + " 0";
+        std::string name = context->getFilename() + " object stream " + std::to_string(stream_id);
+        warn(QPDFExc(qpdf_e_damaged_pdf, name, descr, offset, msg));
+    } else {
+        warn(QPDFExc(qpdf_e_damaged_pdf, input.getName(), object_description, offset, msg));
+    }
 }
 
 void
