@@ -2,9 +2,8 @@
 
 #include <qpdf/QIntC.hh>
 #include <qpdf/QPDFExc.hh>
-#include <qpdf/QUtil.hh>
 
-QPDFXRefEntry::QPDFXRefEntry()
+QPDFXRefEntry::QPDFXRefEntry() // NOLINT (modernize-use-equals-default)
 {
 }
 
@@ -37,8 +36,7 @@ int
 QPDFXRefEntry::getObjStreamNumber() const
 {
     if (this->type != 2) {
-        throw std::logic_error(
-            "getObjStreamNumber called for xref entry of type != 2");
+        throw std::logic_error("getObjStreamNumber called for xref entry of type != 2");
     }
     return QIntC::to_int(this->field1);
 }
@@ -47,8 +45,7 @@ int
 QPDFXRefEntry::getObjStreamIndex() const
 {
     if (this->type != 2) {
-        throw std::logic_error(
-            "getObjStreamIndex called for xref entry of type != 2");
+        throw std::logic_error("getObjStreamIndex called for xref entry of type != 2");
     }
     return this->field2;
 }
