@@ -280,6 +280,16 @@ Stream::getRawStreamData()
     return buf.getBufferSharedPointer();
 }
 
+bool
+Stream::isRootMetadata() const
+{
+    if (!getDict().isDictionaryOfType("/Metadata", "/XML")) {
+        return false;
+    }
+    auto root_metadata = qpdf()->getRoot().getKey("/Metadata");
+    return root_metadata.isSameObjectAs(obj);
+}
+
 bool
 Stream::filterable(
     std::vector<std::shared_ptr<QPDFStreamFilter>>& filters,
@@ -520,6 +530,7 @@ Stream::pipeStreamData(
                 obj->getParsedOffset(),
                 s->length,
                 s->stream_dict,
+                isRootMetadata(),
                 pipeline,
                 suppress_warnings,
                 will_retry)) {
@@ -626,6 +637,12 @@ QPDFObjectHandle::replaceDict(QPDFObjectHandle const& new_dict)
     as_stream(error).replaceDict(new_dict);
 }
 
+bool
+QPDFObjectHandle::isRootMetadata() const
+{
+    return as_stream(error).isRootMetadata();
+}
+
 std::shared_ptr<Buffer>
 QPDFObjectHandle::getStreamData(qpdf_stream_decode_level_e level)
 {
