@@ -111,6 +111,7 @@ test_main()
         check(QPDFObjectHandle::newReal(".34").getJSON(i), "0.34");
         check(QPDFObjectHandle::newReal("-0.56").getJSON(i), "-0.56");
         check(QPDFObjectHandle::newReal("-.78").getJSON(i), "-0.78");
+        check(QPDFObjectHandle::newReal("-78.").getJSON(i), "-78.0");
     }
     JSON jmap2 = JSON::parse(R"({"a": 1, "b": "two", "c": [true]})");
     std::map<std::string, std::string> dvalue;
@@ -161,11 +162,6 @@ test_main()
     assert(jarr.addArrayElement(uninitialized).isNull());
     assert(!uninitialized.isArray());
     assert(!uninitialized.isDictionary());
-    try {
-        uninitialized.checkDictionaryKeySeen("key");
-        assert(false);
-    } catch (std::logic_error&) {
-    }
     std::string st_out = "unchanged";
     assert(!uninitialized.getString(st_out));
     assert(!uninitialized.getNumber(st_out));
