@@ -1,11 +1,8 @@
 #include <qpdf/QPDF.hh>
-#include <qpdf/QPDFObjGen.hh>
-#include <qpdf/QPDFXRefEntry.hh>
 
 #include <cstdlib>
 #include <iostream>
 #include <map>
-#include <string>
 
 int
 main(int argc, char* argv[])
@@ -20,23 +17,18 @@ main(int argc, char* argv[])
         qpdf.processFile(argv[1]);
 
         for (auto const& iter: qpdf.getXRefTable()) {
-            std::cout << iter.first.getObj() << "/" << iter.first.getGen()
-                      << ", ";
+            std::cout << iter.first.getObj() << "/" << iter.first.getGen() << ", ";
             switch (iter.second.getType()) {
             case 0:
                 std::cout << "free entry" << std::endl;
                 break;
             case 1:
-                std::cout << "uncompressed, offset = "
-                          << iter.second.getOffset() << " (0x" << std::hex
-                          << iter.second.getOffset() << std::dec << ")"
-                          << std::endl;
+                std::cout << "uncompressed, offset = " << iter.second.getOffset() << " (0x"
+                          << std::hex << iter.second.getOffset() << std::dec << ")" << std::endl;
                 break;
             case 2:
-                std::cout << "compressed, stream number = "
-                          << iter.second.getObjStreamNumber()
-                          << ", stream index = "
-                          << iter.second.getObjStreamIndex() << std::endl;
+                std::cout << "compressed, stream number = " << iter.second.getObjStreamNumber()
+                          << ", stream index = " << iter.second.getObjStreamIndex() << std::endl;
                 break;
             default:
                 std::cerr << "unknown" << std::endl;
